@@ -93,7 +93,7 @@ struct iovec;
  *      ipv4:192.168.1.1:143
  *
  * Callers should not try to parse the string! The should use additional methods
- * of the specific tsocket_address implemention to get more details.
+ * of the specific tsocket_address implementation to get more details.
  *
  * @param[in]  addr     The address to convert.
  *
@@ -539,6 +539,49 @@ int _tsocket_address_inet_from_strings(TALLOC_CTX *mem_ctx,
 					   __location__)
 #endif
 
+#ifdef DOXYGEN
+/**
+ * @brief Create a tsocket_address for ipv4 and ipv6 endpoint addresses.
+ *
+ * @param[in]  mem_ctx  The talloc memory context to use.
+ *
+ * @param[in]  fam      The family can be can be "ipv4", "ipv6" or "ip". With
+ *                      "ip" it autodetects "ipv4" or "ipv6" based on the
+ *                      addr.
+ *
+ * @param[in]  host_port_addr   A valid ip address string based on the
+ *                      selected family (dns names are not allowed!). A port
+ *                      number may follow sepatated by a colon. IPv6 may be
+ *                      surrounded in square brackets, and these are required
+ *                      if appending a port number. It's valid to pass NULL,
+ *                      which gets mapped to "0.0.0.0" or "::".
+ *
+ * @param[in]  default_port  A valid port number for the default port if none
+ *                      given.
+ *
+ * @param[out] _addr    A tsocket_address pointer to store the information.
+ *
+ * @return              0 on success, -1 on error with errno set.
+ */
+int tsocket_address_inet_from_hostport_strings(TALLOC_CTX *mem_ctx,
+					       const char *fam,
+					       const char *host_port_addr,
+					       uint16_t default_port,
+					       struct tsocket_address **_addr);
+#else
+int _tsocket_address_inet_from_hostport_strings(TALLOC_CTX *mem_ctx,
+						const char *fam,
+						const char *host_port_addr,
+						uint16_t default_port,
+						struct tsocket_address **_addr,
+						const char *location);
+
+#define tsocket_address_inet_from_hostport_strings(                            \
+    mem_ctx, fam, host_port_addr, default_port, _addr)                         \
+	_tsocket_address_inet_from_hostport_strings(                           \
+	    mem_ctx, fam, host_port_addr, default_port, _addr, __location__)
+#endif
+
 /**
  * @brief Get the address of an 'inet' tsocket_address as a string.
  *
@@ -996,16 +1039,16 @@ int _tsocket_address_bsd_from_sockaddr(TALLOC_CTX *mem_ctx,
  * @return              0 on success, -1 on error with errno set.
  */
 int tsocket_address_bsd_from_samba_sockaddr(TALLOC_CTX *mem_ctx,
-					const struct samba_sockaddr *s_addr,
+					const struct samba_sockaddr *xs_addr,
 					struct tsocket_address **t_addr);
 #else
 int _tsocket_address_bsd_from_samba_sockaddr(TALLOC_CTX *mem_ctx,
-					 const struct samba_sockaddr *s_addr,
+					 const struct samba_sockaddr *xs_addr,
 					 struct tsocket_address **t_addr,
 					 const char *location);
 
-#define tsocket_address_bsd_from_samba_sockaddr(mem_ctx, s_addr, t_addr) \
-	_tsocket_address_bsd_from_samba_sockaddr(mem_ctx, s_addr, t_addr, \
+#define tsocket_address_bsd_from_samba_sockaddr(mem_ctx, xs_addr, t_addr) \
+	_tsocket_address_bsd_from_samba_sockaddr(mem_ctx, xs_addr, t_addr, \
 						 __location__)
 #endif
 
@@ -1208,7 +1251,7 @@ int tstream_readv_pdu_queue_recv(struct tevent_req *req, int *perrno);
  *
  * This function queues an iovector for sending to destination through an
  * existing stream socket. The async callback is triggered when the whole
- * vectror has been delivered to the underlying system socket.
+ * vector has been delivered to the underlying system socket.
  *
  * The caller needs to make sure that all non-scalar input parameters hang
  * around for the whole lifetime of the request.
